pub trait NavSolution<T>: Estimate<Spacecraft>where
T: State,
DefaultAllocator: Allocator<<T as State>::Size> + Allocator<<T as State>::Size, <T as State>::Size> + Allocator<<T as State>::VecLength>,{
// Required methods
fn orbital_state(&self) -> Orbit;
fn expected_state(&self) -> Orbit;
}Expand description
A trait to store a navigation solution, can be used in conjunction with KfEstimate
Required Methods
fn orbital_state(&self) -> Orbit
Sourcefn expected_state(&self) -> Orbit
fn expected_state(&self) -> Orbit
Returns the nominal state as computed by the dynamics
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".